ν42 personal blog

Optimization story: Switching from GMP to gcc's __int128 reduced run time by 95%

A flash of intuition while trying to find a way to lend brian d foy a hand in his search for excellent numbers helped me reduce run time by 95 percent.
Points
129
HN comments
40
Submissions
2
Cited by
0 commenters

Systems & PerformanceSoftware Engineering2016

On Hacker News

SubmittedTitle on HNPointsComments
Jan 15, 2016Optimization story: Switching from GMP to gcc's __int128 reduced run time by 95% by nanis12931
Jul 28, 2021Switching from GMP to GCC's __int128 reduced run time by 95% (2016) by optimalsolver719

More from ν42

All 2 posts →

Related posts from the same era